StrategyCategory enum

Categories of execution strategies for validation during chaining.

Inheritance
Available extensions

Values

timing → const StrategyCategory

Timing strategies control when to execute (debounce, throttle)

concurrency → const StrategyCategory

Concurrency strategies control how to handle concurrent executions (takeLatest, takeLeading, sequential)

resilience → const StrategyCategory

Resilience strategies control how to handle failures (retry, retryWithBackoff)

chained → const StrategyCategory

Chained strategies composed of multiple strategies

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<StrategyCategory>
A constant List of the values in this enum, in order of their declaration.