DuplicateCategoryException class
Exception thrown when attempting to chain strategies of the same category.
- Implemented types
Constructors
- DuplicateCategoryException({required StrategyCategory category, required String firstName, required String secondName})
- Creates a DuplicateCategoryException with the conflicting details.
Properties
- category → StrategyCategory
-
The conflicting strategy category.
final
- firstName → String
-
The name of the first strategy with this category.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondName → String
-
The name of the second strategy with this category.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited